@@ -29,11 +29,10 @@ pub struct ContinuousAxis {
 
 impl ContinuousAxis {
     /// Constructs a new ContinuousAxis
-    pub fn new(lower: f64, upper: f64) -> ContinuousAxis {
-        let default_max_ticks = 6;
+    pub fn new(lower: f64, upper: f64, max_ticks: usize) -> ContinuousAxis {
         ContinuousAxis {
             range: Range::new(lower, upper),
-            ticks: calculate_ticks(lower, upper, default_max_ticks),
+            ticks: calculate_ticks(lower, upper, max_ticks),
             label: "".into(),
         }
     }
@@ -146,14 +145,28 @@ impl Iterator for TickSteps {
     }
 }
 
+/**
+This function exists to fix subtle floating point numbers like 0.30000000000000004
+In the longer-term is should be moved to something in the presentation layer
+*/
+fn round(x: f64) -> f64 {
+    (x * 1000000000000000.0).round() / 1000000000000000.0
+}
+
 fn generate_ticks(min: f64, max: f64, step_size: f64) -> Vec<f64> {
+    // "fix" just makes sure there are no floating-point errors
+    fn fix(x: f64) -> f64 {
+        const PRECISION: f64 = 100000_f64;
+        (x * PRECISION).round() / PRECISION
+    }
+
     let mut ticks: Vec<f64> = vec![];
     if min <= 0.0 {
         if max >= 0.0 {
             // standard spanning axis
             ticks.extend(
                 (1..)
-                    .map(|n| -1.0 * f64::from(n) * step_size)
+                    .map(|n| -1.0 * fix(f64::from(n) * step_size))
                     .take_while(|&v| v >= min)
                     .collect::<Vec<f64>>()
                     .iter()
@@ -162,14 +175,14 @@ fn generate_ticks(min: f64, max: f64, step_size: f64) -> Vec<f64> {
             ticks.push(0.0);
             ticks.extend(
                 (1..)
-                    .map(|n| f64::from(n) * step_size)
+                    .map(|n| fix(f64::from(n) * step_size))
                     .take_while(|&v| v <= max),
             );
         } else {
             // entirely negative axis
             ticks.extend(
                 (1..)
-                    .map(|n| -1.0 * f64::from(n) * step_size)
+                    .map(|n| -1.0 * fix(f64::from(n) * step_size))
                     .skip_while(|&v| v > max)
                     .take_while(|&v| v >= min)
                     .collect::<Vec<f64>>()
@@ -181,7 +194,7 @@ fn generate_ticks(min: f64, max: f64, step_size: f64) -> Vec<f64> {
         // entirely positive axis
         ticks.extend(
             (1..)
-                .map(|n| f64::from(n) * step_size)
+                .map(|n| fix(f64::from(n) * step_size))
                 .skip_while(|&v| v < min)
                 .take_while(|&v| v <= max),
         );
@@ -384,15 +397,10 @@ mod tests {
         );
 
         assert_eq!(calculate_ticks(-10.0, -3.0, 6), [-10.0, -8.0, -6.0, -4.0]);
-    }
 
-    #[test]
-    #[should_panic(expected = "assertion failed")]
-    fn test_todo() {
-        // This should work but there is currently a bug in how the rounding is performed.
-        // generate_ticks() does `(3 as f64) * step_size` which when step_size is 0.1 gives
-        // 0.30000000000000004 rather than 1.3
-        // Maybe we just want to fix this at display in which case this test can be removed.
+        // test rounding
         assert_eq!(calculate_ticks(1.0, 1.5, 6), [1.0, 1.1, 1.2, 1.3, 1.4, 1.5]);
+        assert_eq!(calculate_ticks(0.0, 1.0, 6), [0.0, 0.2, 0.4, 0.6, 0.8, 1.0]);
+        assert_eq!(calculate_ticks(0.0, 0.3, 4), [0.0, 0.1, 0.2, 0.3]);
     }
 }
